@@ -48,9 +48,12 @@ QString ProfileEditorBackend::displayName() const
 QString ProfileEditorBackend::displayNameHtml() const
 {
     if (m_account != nullptr) {
-        return TextHandler::replaceCustomEmojis(m_account->customEmojis(), m_displayName);
+        if (m_displayName.isEmpty()) {
+            return m_account->username();
+        }
+        return TextHandler::replaceCustomEmojis(m_account->customEmojis(), displayName());
     } else {
-        return m_displayName;
+        return displayName();
     }
 }
 
@@ -230,6 +233,10 @@ void ProfileEditorBackend::fetchAccountInfo()
         Q_ASSERT(json.isObject());
         const auto obj = json.object();
         setDisplayName(obj["display_name"_L1].toString());
+        // to handle cases where display name is empty, and the signal would never be sent otherwise
+        if (m_displayName.isEmpty()) {
+            Q_EMIT displayNameChanged();
+        }
         const auto source = obj["source"_L1].toObject();
         setNote(source["note"_L1].toString());
         setBot(obj["bot"_L1].toBool());
@@ -285,7 +292,7 @@ void ProfileEditorBackend::save()
     discoverablePart.setBody(discoverable() ? "1" : "0");
     multiPart->append(discoverablePart);
 
-    for (int i = 0; i < maxFields(); i++) {
+    for (int i = 0; i < m_fields.size(); i++) {
         QHttpPart fieldNamePart;
         fieldNamePart.setHeader(QNetworkRequest::ContentDispositionHeader, QStringLiteral("form-data; name=\"fields_attributes[%1][name]\"").arg(i));
         fieldNamePart.setBody(m_fields[i]["name"_L1].toString().toUtf8());
