@@ -15,7 +15,7 @@ public:
         setError(NetworkError::NoError, QString());
         setFinished(true);
 
-        apiResult.setFileName(QLatin1String(DATA_DIR) + QLatin1Char('/') + jsonFile);
+        apiResult.setFileName(QLatin1String(DATA_DIR "/%1").arg(jsonFile));
         apiResult.open(QIODevice::ReadOnly);
     }
 
@@ -33,5 +33,10 @@ public:
     {
     }
 
+    void setRawHeader(const QByteArray &headerName, const QByteArray &value)
+    {
+        QNetworkReply::setRawHeader(headerName, value);
+    }
+
     QFile apiResult;
 };
