@@ -3,6 +3,8 @@
 
 #include "editor/reporteditorbackend.h"
 
+#include <QUrlQuery>
+
 #include "account/accountmanager.h"
 
 using namespace Qt::StringLiterals;
@@ -34,7 +36,7 @@ void ReportEditorBackend::submit()
         formdata.addQueryItem(QStringLiteral("status_ids[]"), m_postId);
     }
 
-    account->post(account->apiUrl(QStringLiteral("/api/v1/reports")), formdata, true, this, [=](QNetworkReply *) {
+    account->post(account->apiUrl(QStringLiteral("/api/v1/reports")), formdata, true, this, [this](QNetworkReply *) {
         Q_EMIT reported();
     });
 }
