@@ -23,9 +23,8 @@
 #include <KWindowSystem>
 #include <QDBusConnection>
 #endif
-#include <KIconTheme>
-#include <KLocalizedQmlContext>
 #include <KLocalizedString>
+#include <KirigamiApp>
 
 #include <QNetworkProxyFactory>
 
@@ -41,19 +40,11 @@
 #include "utils/blurhashimageprovider.h"
 #include "utils/colorschemer.h"
 
-#ifdef Q_OS_WINDOWS
-#include <Windows.h>
-#endif
-
 #ifdef TEST_MODE
 #include "autotests/helperreply.h"
 #include "autotests/mockaccount.h"
 #endif
 
-#if __has_include("KCrash")
-#include <KCrash>
-#endif
-
 using namespace Qt::Literals::StringLiterals;
 
 #ifdef Q_OS_ANDROID
@@ -61,42 +52,24 @@ Q_DECL_EXPORT
 #endif
 int main(int argc, char *argv[])
 {
-    KIconTheme::initTheme();
     QNetworkProxyFactory::setUseSystemConfiguration(true);
 
 #ifdef HAVE_WEBVIEW
     QtWebView::initialize();
 #endif
 
+    KirigamiApp::App app(argc, argv);
+    KirigamiApp kapp;
+
 #ifdef Q_OS_ANDROID
-    QGuiApplication app(argc, argv);
     app.connect(&app, &QGuiApplication::applicationStateChanged, [](Qt::ApplicationState state) {
         if (state == Qt::ApplicationActive) {
             AndroidUtils::instance().checkPendingIntents();
         }
     });
-    QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
-#else
-    QApplication app(argc, argv);
-    // Default to org.kde.desktop style unless the user forces another style
-    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
-        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
-    }
 #endif
 
-#ifdef Q_OS_WINDOWS
-    if (AttachConsole(ATTACH_PARENT_PROCESS)) {
-        freopen("CONOUT$", "w", stdout);
-        freopen("CONOUT$", "w", stderr);
-    }
-
-    QApplication::setStyle(QStringLiteral("breeze"));
-    auto font = app.font();
-    font.setPointSize(10);
-    app.setFont(font);
-#endif
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("tokodon"));
-
     QCoreApplication::setOrganizationName(QStringLiteral("KDE"));
 
     KAboutData about(QStringLiteral("tokodon"),
@@ -122,19 +95,15 @@ int main(int argc, char *argv[])
     KAboutData::setApplicationData(about);
     QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.tokodon")));
 
-#if __has_include("KCrash")
-    KCrash::initialize();
-#endif
-
     QCommandLineParser parser;
     parser.setApplicationDescription(i18n("Browse the Fediverse"));
-    parser.addPositionalArgument(QStringLiteral("urls"), i18n("Supports https, tokodon and web+ap url scheme"));
+    parser.addPositionalArgument(QStringLiteral("url"), i18n("Supports https, and web+ap url schemes."));
 
-    QCommandLineOption shareOption(QStringLiteral("share"), i18n("Share a line of text in the standalone composer."), i18n("The text to share."));
+    QCommandLineOption shareOption(QStringLiteral("share"));
     shareOption.setFlags(QCommandLineOption::Flag::HiddenFromHelp);
     parser.addOption(shareOption);
 
-    QCommandLineOption notifyOption(QStringLiteral("dbus-activated"), i18n("Internal usage only."));
+    QCommandLineOption notifyOption(QStringLiteral("dbus-activated"));
     notifyOption.setFlags(QCommandLineOption::Flag::HiddenFromHelp);
     parser.addOption(notifyOption);
 
@@ -210,8 +179,6 @@ int main(int argc, char *argv[])
         }
     });
 #endif
-    KLocalization::setupLocalizedContext(&engine);
-
     NetworkAccessManagerFactory namFactory;
     engine.setNetworkAccessManagerFactory(&namFactory);
 
@@ -245,11 +212,11 @@ int main(int argc, char *argv[])
 #endif
 
     if (parser.isSet(shareOption)) {
-        engine.loadFromModule("org.kde.tokodon", "StandaloneComposer");
+        kapp.start("org.kde.tokodon", "StandaloneComposer", &engine);
 
         NetworkController::instance().startComposing(parser.value(shareOption));
     } else {
-        engine.loadFromModule("org.kde.tokodon", "Main");
+        kapp.start("org.kde.tokodon", "Main", &engine);
 
         if (!parser.positionalArguments().empty()) {
             NetworkController::instance().openWebApLink(parser.positionalArguments()[0]);
