@@ -15,19 +15,20 @@ bool NotificationGroupingModel::notificationsMatch(const QModelIndex &a, const Q
     const QString aId = a.data(AbstractTimelineModel::CustoRoles::IdRole).toString();
     const QString bId = b.data(AbstractTimelineModel::CustoRoles::IdRole).toString();
 
-    const QVariant aType = a.data(AbstractTimelineModel::CustoRoles::TypeRole);
-    const QVariant bType = b.data(AbstractTimelineModel::CustoRoles::TypeRole);
+    const auto aType = a.data(AbstractTimelineModel::CustoRoles::TypeRole).value<Notification::Type>();
+    const auto bType = b.data(AbstractTimelineModel::CustoRoles::TypeRole).value<Notification::Type>();
+
+    const auto aUnread = a.data(NotificationModel::UnreadRole).toBool();
+    const auto bUnread = b.data(NotificationModel::UnreadRole).toBool();
 
-    // it makes no sense to group poll or edit updates
     // TODO: support grouping follow notifications
-    if (aType == bType
-        && (aType == Notification::Type::Follow || aType == Notification::Type::Poll || aType == Notification::Type::Update
-            || aType == Notification::Type::Status || aType == Notification::Type::AdminSignUp || aType == Notification::Type::AdminReport
-            || aType == Notification::Type::SeveredRelationships || aType == Notification::Type::ModerationWarning)) {
+    switch (aType) {
+    case Notification::Type::Favorite:
+    case Notification::Type::Repeat:
+        return aId == bId && aType == bType && aUnread == bUnread;
+    default:
         return false;
     }
-
-    return aId == bId && aType == bType;
 }
 
 bool NotificationGroupingModel::isGroup(int row) const
@@ -244,6 +245,10 @@ void NotificationGroupingModel::setSourceModel(QAbstractItemModel *sourceModel)
                         Q_EMIT dataChanged(proxyIndex, proxyIndex, roles);
                     }
                 });
+
+        if (auto model = qobject_cast<NotificationModel *>(sourceModel)) {
+            connect(model, &NotificationModel::readMarkerChanged, this, &NotificationGroupingModel::readMarkerChanged);
+        }
     }
 
     endResetModel();
@@ -465,6 +470,12 @@ void NotificationGroupingModel::markAllNotificationsAsRead()
         model->markAllNotificationsAsRead();
 }
 
+bool NotificationGroupingModel::fullyRead() const
+{
+    const auto model = qobject_cast<NotificationModel *>(sourceModel());
+    return !model || model->fullyRead();
+}
+
 void NotificationGroupingModel::actionReply(const QModelIndex &index)
 {
     if (auto model = qobject_cast<NotificationModel *>(sourceModel())) {
