@@ -4,10 +4,11 @@
 #include "utils/colorschemer.h"
 
 #include <KColorSchemeManager>
+#include <QAbstractItemModel>
 
 ColorSchemer::ColorSchemer(QObject *parent)
     : QObject(parent)
-    , c(new KColorSchemeManager(this))
+    , c(KColorSchemeManager::instance())
 {
 }
 
@@ -46,4 +47,4 @@ QString ColorSchemer::nameForIndex(int index) const
     return c->model()->data(c->model()->index(index, 0), Qt::DisplayRole).toString();
 }
 
-#include "moc_colorschemer.cpp"
\ No newline at end of file
+#include "moc_colorschemer.cpp"
