@@ -6,7 +6,6 @@
 #include <KJob>
 #include <QSaveFile>
 
-class QNetworkReply;
 class AbstractAccount;
 
 class FileTransferJob final : public KJob
@@ -20,7 +19,7 @@ public:
     };
 
 private:
-    AbstractAccount *m_account = nullptr;
+    AbstractAccount *const m_account;
     QString m_source;
     QString m_destination;
     QScopedPointer<QSaveFile> m_temporaryFile;
